/**
 * JASMINe
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * $Id: Main.java 4798 2009-08-07 12:30:47Z alitokmen $
 */

package org.ow2.jasmine.monitoring.installer.jonas;

import org.apache.commons.cli.BasicParser;
import org.apache.commons.cli.CommandLine;
import org.apache.commons.cli.MissingOptionException;
import org.apache.commons.cli.Option;
import org.apache.commons.cli.OptionBuilder;
import org.apache.commons.cli.Options;
import org.apache.commons.cli.ParseException;

/**
 * @author Julien Legrand
 */
public class Main {

    /**
     * 
     */
    private Options options;

    /**
     * 
     */
    private CommandLine commandline;

    /**
     * 
     */
    private static final String JONAS_ROOT_OPT = "jonas_root";

    /**
     * 
     */
    private static final String JONAS_BASE_OPT = "jonas_base";

    // ------------------------------------------------------------------------
    // Constructor
    // ------------------------------------------------------------------------

    /**
     * 
     */
    public Main(String[] args) {
        initOptions();

        final BasicParser parser = new BasicParser();

        try {
            commandline = parser.parse(options, args);
        } catch (MissingOptionException e) {
            System.err.println(e.getMessage());
            System.exit(0);
        } catch (ParseException e) {
            System.err.println(e.getMessage());
            System.exit(0);
        }
    }

    // ------------------------------------------------------------------------
    // Public methods
    // ------------------------------------------------------------------------

    /**
     * 
     */
    public final void generatedJOnASConfiguration() {
        
        String jonasRoot = "";
        String jonasBase = "";

        if (commandline.hasOption(JONAS_BASE_OPT)) {
            jonasBase = commandline.getOptionValue(JONAS_BASE_OPT);
        }
        
        if (commandline.hasOption(JONAS_ROOT_OPT)) {
            jonasRoot = commandline.getOptionValue(JONAS_ROOT_OPT);
        }

        new JOnASConfigurationGenerator(jonasRoot, jonasBase).configure();

    }

    // ------------------------------------------------------------------------
    // Main method
    // ------------------------------------------------------------------------

    /**
     * @param args
     */
    public static void main(final String[] args) {

        Main main = new Main(args);
        main.generatedJOnASConfiguration();
    }

    // ------------------------------------------------------------------------
    // Private methods
    // ------------------------------------------------------------------------

    /**
     * Initialize command line options
     */
    private void initOptions() {

        options = new Options();

        // JONAS_ROOT
        final Option jonasRoot = OptionBuilder.withArgName(JONAS_ROOT_OPT).hasArg().withDescription(
                "Location of JONAS_ROOT").create(JONAS_ROOT_OPT);
        options.addOption(jonasRoot);

        // JONAS_BASE
        final Option jonasBase = OptionBuilder.withArgName(JONAS_BASE_OPT).isRequired().hasArg().withDescription(
                "Location of JONAS_BASE").create(JONAS_BASE_OPT);
        options.addOption(jonasBase);

    }

}
